# Filename:     tb_comparator.do
# Filetype:     Modelsim Script File
# Date:         8 oct 2012
# Update:       10 oct 2014
# Description:  Script File For Automatic Simulation
# Author:       J. op den Brouw
# State:        Lab
# Error:        -
# Version:      1.2
# Copyright:    (c)2014, De Haagse Hogeschool

# Transcript on, we see output
transcript on

# Recreate working directory
if {[file exists rtl_work]} {
	vdel -lib rtl_work -all
}
vlib rtl_work
vmap work rtl_work

# Loop through all the VHDL files and compile them
foreach vhd_file [ glob *.vhd ] {
	puts "Compiling $vhd_file"
	vcom -93 -work work $vhd_file
}

# Start the simulator
vsim -t 1ns -L rtl_work -L work -voptargs="+acc" comparator

# Log all signals in the design, good if the number
# of signals is small.
add log -r *

# Add all toplevel signals
# Add a number of signals of the simulated design
add list -nodelta -label SW7 sw7
add list -nodelta -label SW6 sw6
add list -nodelta -label SW5 sw5
add list -nodelta -label SW4 sw4
add list -nodelta -width 3 -label SW3 sw3
add list -nodelta -label SW2 sw2
add list -nodelta -label SW1 sw1
add list -nodelta -label SW0 sw0

add list -nodelta -width 3 -label S3 s3
add list -nodelta -label S2 s2
add list -nodelta -label S1 s1
add list -nodelta -label S0 s0

if {[find signal N] != ""} {
	# signal N exists
	add list -nodelta -width 5 -label N n
} else {
	# silently use S3 as N
	add list -nodelta -width 5 -label N s3
	puts "Using S3 as N."
}
if {[find signal V] != ""} {
	# signal V exists
	add list -nodelta -width 1 -label V v
} else {
	puts "No V signal found!!!"
}
if {[find signal C] != ""} {
	# signal C exists
	add list -nodelta -width 1 -label C c
} else {
	puts "No C signal found!!!"
}


add list -nodelta -width 5 -label LEDG2 ledg2
add list -nodelta -label LEDG1 ledg1
add list -nodelta -label LEDG0 ledg0

add list -nodelta -width 5 -label A -dec {A {SW7 SW6 SW5 SW4}}
add list -nodelta -width 3 -label B -dec {B {SW3 SW2 SW1 SW0}}
add list -nodelta -width 3 -label S -dec {S {S3 S2 S1 S0}}

add list -nodelta -width 5 -label AgtB ledg2
add list -nodelta -label AeqB ledg1
add list -nodelta -label AltB ledg0

# Open List window
noview Wave
noview Signals
noview Structure
view list

# Apply stimuli
force SW0 0 0, 1 1   -repeat 2   -cancel 256
force SW1 0 0, 1 2   -repeat 4   -cancel 256
force SW2 0 0, 1 4   -repeat 8   -cancel 256
force SW3 0 0, 1 8   -repeat 16  -cancel 256
force SW4 0 0, 1 16  -repeat 32  -cancel 256
force SW5 0 0, 1 32  -repeat 64  -cancel 256
force SW6 0 0, 1 64  -repeat 128 -cancel 256
force SW7 0 0, 1 128 -repeat 256 -cancel 256


# Run simulation for 256 ns
run 255 ns
